% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_and_reporting.r
\name{umxCI}
\alias{umxCI}
\title{Add (and, optionally, run) confidence intervals to a structural model.}
\usage{
umxCI(model = NULL, which = c("ALL", NA, "list of your making"),
  remove = FALSE, run = c("no", "yes", "if necessary", "show"),
  interval = 0.95, type = c("both", "lower", "upper"),
  showErrorCodes = TRUE)
}
\arguments{
\item{model}{The \code{\link{mxModel}} you wish to report \code{\link{mxCI}}s on}

\item{which}{What CIs to add: c("ALL", NA, "list of your making")}

\item{remove}{= FALSE (if set, removes existing specified CIs from the model)}

\item{run}{Whether or not to compute the CIs. Valid values = "no" (default), "yes", "if necessary".
'show' means print the intervals if computed, or list their names if not.}

\item{interval}{The interval for newly added CIs (defaults to 0.95)}

\item{type}{The type of CI (defaults to "both", options are "lower" and  "upper")}

\item{showErrorCodes}{Whether to show errors (default == TRUE)}
}
\value{
- \code{\link{mxModel}}
}
\description{
umxCI adds mxCI() calls for all free parameters in a model, 
runs the CIs, and reports a neat summary.
}
\details{
This function also reports any problems computing a CI. The codes are standard OpenMx errors and warnings
\itemize{
\item 1: The final iterate satisfies the optimality conditions to the accuracy requested, but the sequence of iterates has not yet converged. NPSOL was terminated because no further improvement could be made in the merit function (Mx status GREEN)
\item 2: The linear constraints and bounds could not be satisfied. The problem has no feasible solution.
\item 3: The nonlinear constraints and bounds could not be satisfied. The problem may have no feasible solution.
\item 4: The major iteration limit was reached (Mx status BLUE).
\item 6: The model does not satisfy the first-order optimality conditions to the required accuracy, and no improved point for the merit function could be found during the final linesearch (Mx status RED)
\item 7: The function derivatives returned by funcon or funobj appear to be incorrect.
\item 9: An input parameter was invalid
}

If runCIs is FALSE, the function simply adds CIs to be computed and returns the model.
}
\examples{
require(umx)
data(demoOneFactor)
latents  = c("G")
manifests = names(demoOneFactor)
m1 <- umxRAM("One Factor", data = mxData(cov(demoOneFactor), type = "cov", numObs = 500),
	umxPath(latents, to = manifests),
	umxPath(var = manifests),
	umxPath(var = latents, fixedAt = 1)
)
m1$intervals # none yet list()
m1 = umxCI(m1)
m1$intervals # $G_to_x1
m1 = umxCI(m1, remove = TRUE) # Add CIs for all free parameters, and return model
data(twinData) 
selDVs = c("bmi1","bmi2")
mzData <- as.matrix(subset(twinData, zygosity == "MZFF", selDVs))
dzData <- as.matrix(subset(twinData, zygosity == "DZFF", selDVs))
m1 = umxACE(selDVs = selDVs, dzData = dzData, mzData = mzData)
\dontrun{
umxCI(m1, run = "show") # show what will be requested
umxCI(m1, run = "yes") # actually compute the CIs
# Don't force update of CIs, but if they were just added, then calculate them
umxCI(m1, run = "if necessary")
m1 = umxCI(m1, remove = TRUE) # remove them all
m1$intervals # none!
umxParameters(m1) # see what's available
m1 = umxCI(m1, "a_r1c1", run = "yes")
}
}
\references{
- http://www.github.com/tbates/umx/
}
\seealso{
- \code{\link{mxCI}}, \code{\link{umxLabel}}, \code{\link{umxRun}}

Other Reporting functions: \code{\link{RMSEA.MxModel}},
  \code{\link{RMSEA.summary.mxmodel}}, \code{\link{RMSEA}},
  \code{\link{extractAIC.MxModel}}, \code{\link{loadings}},
  \code{\link{plot.MxModel}},
  \code{\link{residuals.MxModel}},
  \code{\link{umxCI_boot}}, \code{\link{umxCompare}},
  \code{\link{umxConfint}}, \code{\link{umxExpCov}},
  \code{\link{umxExpMeans}}, \code{\link{umxFitIndices}},
  \code{\link{umxPlotACEcov}}, \code{\link{umxPlotACEv}},
  \code{\link{umxPlotACE}}, \code{\link{umxPlotCP}},
  \code{\link{umxPlotGxE}}, \code{\link{umxPlotIP}},
  \code{\link{umxSummary.MxModel}},
  \code{\link{umxSummaryACEv}},
  \code{\link{umxSummaryACE}}, \code{\link{umx_drop_ok}},
  \code{\link{umx_standardize_RAM}}
}
